use crate::events::Event;
use crate::handles::online_users_update::{online_messages, send_online_users_resp};
use tokio::sync::mpsc::UnboundedSender;
use crate::handles::handle_agora_call::handle_agora_call;

pub async fn handle_ws_msg(
    msg_type: String,
    from_id: String,
    event_sender: UnboundedSender<Event>,
    connection_time: u128,
) {
    match msg_type.as_str() {
        "GetCompanyUserList" => {
            println!("收到客户端获取在线用户列表 {}", &from_id);
            // 需要主动发送在线人员更新事件
            if let Ok(online_users_json) = send_online_users_resp().await {
                if let Ok(formatted_json) = online_messages(online_users_json, from_id.clone()) {
                    if let Err(e) = event_sender.send(Event::SendClientMessage(
                        (from_id.clone(), connection_time),
                        formatted_json,
                        false,
                    )) {
                        println!(
                            "客户端要求更新在线列表 {}发送在线用户列表失败 {:?}",
                            &from_id, e
                        );
                    } else {
                        println!("客户端要求更新在线列表 {}发送在线用户列表成功", &from_id);
                    }
                }
            }
        }
        "Call" | "CancelCall" => {
            handle_agora_call(&msg_type, &from_id, &event_sender, &connection_time).await;
        }
        _ => {}
    }
}
